@@ -76,7 +76,7 @@ async def call_and_log_error(co):
 
 
 async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, createrpc,
-                        updaterpc, field_map, noact):
+                        updaterpc, field_map, deactivate, noact):
     """
     Function to sync python bss-sourced objects to model objects.
     Pass in the model and the company_uuid and source we are working on.
@@ -148,7 +148,7 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                         mods['attachment_req'] = set_att_req
                     await call_and_log_error(
                         updaterpc(company_uuid=company_uuid, uuid=mobj.uuid, **mods))
-        else:
+        elif deactivate:  # sync deletes unless explicitly told not to
             if not mobj.inactive:
                 logging.info("sync_preseem_model(%s): deactivate %s %s", source,
                              type(mobj).__name__.lower(), UUID(bytes=mobj.uuid))
@@ -189,6 +189,7 @@ async def sync_preseem_model(preseem_model,
                              routers=None,
                              olts=None,
                              nm_model=None,
+                             deactivate=None,
                              noact=False,
                              verbose=0):
     """
@@ -371,6 +372,7 @@ async def sync_preseem_model(preseem_model,
                                                preseem_model.Package.Create,
                                                preseem_model.Package.Update,
                                                _package_field_map,
+                                               deactivate=deactivate is not False,
                                                noact=noact)
 
         new_accounts = []
@@ -402,6 +404,7 @@ async def sync_preseem_model(preseem_model,
                                                preseem_model.Account.Create,
                                                preseem_model.Account.Update,
                                                _account_field_map,
+                                               deactivate=deactivate is not False,
                                                noact=noact)
 
         if services is not None:
@@ -466,6 +469,7 @@ async def sync_preseem_model(preseem_model,
                                 preseem_model.Service.Create,
                                 preseem_model.Service.Update,
                                 _service_field_map,
+                                deactivate=deactivate is not False,
                                 noact=noact)
 
         for bss_objs, source_type in (routers, Router), (olts, Olt):
@@ -517,6 +521,7 @@ async def sync_preseem_model(preseem_model,
                     preseem_model.Element.CreateElementDiscovery,
                     preseem_model.Element.UpdateElementDiscovery,
                     _elem_field_map,
+                    deactivate=deactivate is not False,
                     noact=noact)
                 for mobj in discs + new_objs:
                     sobj = bss_objs.get(mobj.source_id)
