@@ -1384,6 +1384,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         pon.name = None
         self.assertEqual(pon.name, None)
 
+        self.assertEqual(pon.description, None)
+        pon.description = 'pon-description'
+        self.assertEqual(pon.description, 'pon-description')
+        pon.description = None
+        self.assertEqual(pon.description, None)
+
         # PonLink
         ponlink = pon.links.add()
         poller_hash = sha256().digest()
